summaryrefslogtreecommitdiffstats
path: root/src/BlockEntities/JukeboxEntity.h
diff options
context:
space:
mode:
authorHowaner <franzi.moos@googlemail.com>2014-02-21 22:26:04 +0100
committerHowaner <franzi.moos@googlemail.com>2014-02-21 22:26:04 +0100
commitb3339a6617ffd7b8358c83348e6ccfa8eba2eb92 (patch)
tree71f9e530e37c2024b9d754179d9769631175a9df /src/BlockEntities/JukeboxEntity.h
parentRemove users.ini generation in Player.cpp and use the CheckUsers() Function (diff)
downloadcuberite-b3339a6617ffd7b8358c83348e6ccfa8eba2eb92.tar
cuberite-b3339a6617ffd7b8358c83348e6ccfa8eba2eb92.tar.gz
cuberite-b3339a6617ffd7b8358c83348e6ccfa8eba2eb92.tar.bz2
cuberite-b3339a6617ffd7b8358c83348e6ccfa8eba2eb92.tar.lz
cuberite-b3339a6617ffd7b8358c83348e6ccfa8eba2eb92.tar.xz
cuberite-b3339a6617ffd7b8358c83348e6ccfa8eba2eb92.tar.zst
cuberite-b3339a6617ffd7b8358c83348e6ccfa8eba2eb92.zip
Diffstat (limited to '')
-rw-r--r--src/BlockEntities/JukeboxEntity.h16
1 files changed, 13 insertions, 3 deletions
diff --git a/src/BlockEntities/JukeboxEntity.h b/src/BlockEntities/JukeboxEntity.h
index 734d7bb66..01ce52494 100644
--- a/src/BlockEntities/JukeboxEntity.h
+++ b/src/BlockEntities/JukeboxEntity.h
@@ -37,10 +37,20 @@ public:
int GetRecord(void);
void SetRecord(int a_Record);
- void PlayRecord(void);
- /// Ejects the currently held record as a pickup. Does nothing when no record inserted.
- void EjectRecord(void);
+ /** Play a Record. Return false, when a_Record isn't a Record */
+ bool PlayRecord(int a_Record);
+
+ /** Ejects the currently held record as a pickup. Return false when no record inserted. */
+ bool EjectRecord(void);
+
+ /** Is in the Jukebox a Record? */
+ bool IsPlayingRecord(void);
+
+ static bool IsRecordItem(int a_Item)
+ {
+ return ((a_Item >= E_ITEM_FIRST_DISC) && (a_Item <= E_ITEM_LAST_DISC));
+ }
// tolua_end